@@ -23,12 +23,14 @@
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     use Version::Dotted;
+#pod     use Version::Dotted;            # import nothing
+#pod     use Version::Dotted qw{ qv };   # import qv
 #pod
 #pod     # Construct:
-#pod     $v = Version::Dotted->new( v1.2.3 );    # v1.2.3
-#pod     $v = Version::Dotted->new( '1.2.0' );   # v1.2 (trailing zero parts ignored)
-#pod     $v = Version::Dotted->new( 'v1' );      # v1
+#pod     $v = Version::Dotted->new( v1.2.3 );    # the same as qv( v1.2.3 )
+#pod     $v = qv( v1.2.3 );      # v1.2.3
+#pod     $v = qv( '1.2.0' );     # v1.2 (trailing zero parts ignored)
+#pod     $v = qv( 'v1' );        # v1
 #pod
 #pod     # Access individual parts:
 #pod     $p = $v->part( $i );    # Get i-th part.
@@ -86,10 +88,9 @@
 #pod
 #pod =item *
 #pod
-#pod C<CPAN::Meta::Spec> defines three possible release status: C<stable>, C<testing>, and C<unstable>.
-#pod Word "alpha" is used in the description of C<unstable> release, while C<testing> release is
-#pod described as "beta". There is also requirement that C<stable> release version should not contain
-#pod underscore.
+#pod C<CPAN::Meta::Spec> defines status as one of: C<stable>, C<testing>, and C<unstable>. Word "alpha"
+#pod is used in the description of C<unstable> release, while C<testing> release is described as "beta".
+#pod There is also requirement that C<stable> release version should not contain underscore.
 #pod
 #pod =item *
 #pod
@@ -122,7 +123,7 @@ use warnings::register;
 use version 0.77 qw{};
 
 # ABSTRACT: TODO
-our $VERSION = 'v0.0.0_01'; # TRIAL VERSION
+our $VERSION = 'v0.0.0_02'; # TRIAL VERSION
 
 use parent 'version';
 use overload (
@@ -389,10 +390,45 @@ sub numify {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =head1 EXPORT
+#pod
+#pod The module exports nothing by default. The module installs C<qv> function (I<not> a method) into
+#pod caller namespace by explicit request:
+#pod
+#pod     use Version::Dotted qw{ qv };
+#pod
+#pod The module (unlike to C<version>) does not play any tricks with importer's C<VERSION> and/or
+#pod C<UNIVERSAL::VERSION>.
+#pod
+#pod =func qv
+#pod
+#pod Shortcut for C<Version::Dotted->new>.
+#pod
+#pod     $v = Version::Dotted->new( $arg );
+#pod     $v = qv( $arv );
+#pod
+#pod Note: There is I<no> function C<Version::Dotted::qv>, C<qv> function is installed into importer
+#pod package by explicit request, see L</"EXPORT">.
+#pod
+#pod =cut
+
 #   We have to redefine parents' import. Otherwise we will export `qv` into importer namespace by
 #   default. Explicit import of `qv` could be a good idea, though.
 
 sub import {
+    my ( $class, @list ) = @_;
+    my $pkg = caller();
+    my %args = map( { $_ => 1 } @list );
+    if ( delete( $args{ qv } ) ) {
+        no strict 'refs';               ## no critic ( ProhibitNoStrict )
+        *{ $pkg . '::qv' } = sub {
+            return $class->new( @_ );
+        };
+    };
+    if ( %args ) {
+        $class->_warn( "Bad $class import: " . join( ', ', map( { "'$_'" } keys( %args ) ) ) );
+    };
+    return;
 };
 
 1;
@@ -523,7 +559,7 @@ Version::Dotted - TODO
 
 =head1 VERSION
 
-Version v0.0.0_01, released on 2016-12-25 00:26 UTC.
+Version v0.0.0_02, released on 2016-12-25 22:38 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
@@ -534,12 +570,14 @@ TODO
 
 =head1 SYNOPSIS
 
-    use Version::Dotted;
+    use Version::Dotted;            # import nothing
+    use Version::Dotted qw{ qv };   # import qv
 
     # Construct:
-    $v = Version::Dotted->new( v1.2.3 );    # v1.2.3
-    $v = Version::Dotted->new( '1.2.0' );   # v1.2 (trailing zero parts ignored)
-    $v = Version::Dotted->new( 'v1' );      # v1
+    $v = Version::Dotted->new( v1.2.3 );    # the same as qv( v1.2.3 )
+    $v = qv( v1.2.3 );      # v1.2.3
+    $v = qv( '1.2.0' );     # v1.2 (trailing zero parts ignored)
+    $v = qv( 'v1' );        # v1
 
     # Access individual parts:
     $p = $v->part( $i );    # Get i-th part.
@@ -597,10 +635,9 @@ The C<version> module names a version containing underscore "alpha version" and
 
 =item *
 
-C<CPAN::Meta::Spec> defines three possible release status: C<stable>, C<testing>, and C<unstable>.
-Word "alpha" is used in the description of C<unstable> release, while C<testing> release is
-described as "beta". There is also requirement that C<stable> release version should not contain
-underscore.
+C<CPAN::Meta::Spec> defines status as one of: C<stable>, C<testing>, and C<unstable>. Word "alpha"
+is used in the description of C<unstable> release, while C<testing> release is described as "beta".
+There is also requirement that C<stable> release version should not contain underscore.
 
 =item *
 
@@ -623,6 +660,16 @@ more generic term "trial": trial could be either "alpha", "beta", or "rc".
 
 However, C<Version::Dotted> does not define C<is_trial> method but leaves this for subclasses.
 
+=head1 EXPORT
+
+The module exports nothing by default. The module installs C<qv> function (I<not> a method) into
+caller namespace by explicit request:
+
+    use Version::Dotted qw{ qv };
+
+The module (unlike to C<version>) does not play any tricks with importer's C<VERSION> and/or
+C<UNIVERSAL::VERSION>.
+
 =head1 CLASS METHODS
 
 =head2 C<new>
@@ -698,6 +745,18 @@ stringification is always a dotted version string with leading C<'v'>, e. g.:
 
     Version::Dotted->new( 1.2 )->stringify eq 'v1.2';
 
+=head1 FUNCTIONS
+
+=head2 qv
+
+Shortcut for C<Version::Dotted->new>.
+
+    $v = Version::Dotted->new( $arg );
+    $v = qv( $arv );
+
+Note: There is I<no> function C<Version::Dotted::qv>, C<qv> function is installed into importer
+package by explicit request, see L</"EXPORT">.
+
 =head1 OPERATORS
 
 =head2 C<E<lt>=E<gt>>
