@@ -23,11 +23,12 @@
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     use Version::Dotted::Odd;
+#pod     use Version::Dotted::Odd;           # import nothing
+#pod     use Version::Dotted::Odd qw{ qv };  # import qv
 #pod
 #pod     # Construct:
 #pod     $v = Version::Dotted::Odd->new( v1.0 );     # v1.0.0 (at least 3 parts)
-#pod     $v = Version::Dotted::Odd->new( v1.0.2.5 ); # v1.0.2.5
+#pod     $v = qv( v1.0.2.5 );    # v1.0.2.5
 #pod
 #pod     # Release status:
 #pod     if ( $v->is_trial ) {   # If the second part is odd.
@@ -46,7 +47,7 @@
 #pod
 #pod Version object always has at least 3 parts.
 #pod
-#pod     $v = Version::Dotted::Odd->new( v1 );   # v1.0.0
+#pod     $v = qv( v1 );          # v1.0.0
 #pod     $v->part( 0 ) == 1;     # Parts 0, 1, 2 are always defined.
 #pod     $v->part( 1 ) == 0;     # Zero if not specified explicitly.
 #pod     $v->part( 2 ) == 0;     # ditto
@@ -56,10 +57,10 @@
 #pod
 #pod The second part defines the release status: odd numbers denotes a trial release.
 #pod
-#pod     $v = Version::Dotted::Odd->new( v1.0 ); # $v == v1.0.0
-#pod     $v->is_trial;                           # false
-#pod     $v += v0.1;                             # $v == v1.1.0
-#pod     $v->is_trial;                           # true
+#pod     $v = qv( v1.0 );        # $v == v1.0.0
+#pod     $v->is_trial;           # false
+#pod     $v += v0.1;             # $v == v1.1.0
+#pod     $v->is_trial;           # true
 #pod
 #pod =back
 #pod
@@ -73,7 +74,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: TODO
-our $VERSION = 'v0.0.0_01'; # TRIAL VERSION
+our $VERSION = 'v0.0.0_02'; # TRIAL VERSION
 
 use parent 'Version::Dotted';
 
@@ -150,7 +151,7 @@ Version::Dotted::Odd - TODO
 
 =head1 VERSION
 
-Version v0.0.0_01, released on 2016-12-25 00:26 UTC.
+Version v0.0.0_02, released on 2016-12-25 22:38 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
@@ -161,11 +162,12 @@ TODO
 
 =head1 SYNOPSIS
 
-    use Version::Dotted::Odd;
+    use Version::Dotted::Odd;           # import nothing
+    use Version::Dotted::Odd qw{ qv };  # import qv
 
     # Construct:
     $v = Version::Dotted::Odd->new( v1.0 );     # v1.0.0 (at least 3 parts)
-    $v = Version::Dotted::Odd->new( v1.0.2.5 ); # v1.0.2.5
+    $v = qv( v1.0.2.5 );    # v1.0.2.5
 
     # Release status:
     if ( $v->is_trial ) {   # If the second part is odd.
@@ -184,7 +186,7 @@ This is subclass of C<Version::Dotted>. Two features distinct it from the parent
 
 Version object always has at least 3 parts.
 
-    $v = Version::Dotted::Odd->new( v1 );   # v1.0.0
+    $v = qv( v1 );          # v1.0.0
     $v->part( 0 ) == 1;     # Parts 0, 1, 2 are always defined.
     $v->part( 1 ) == 0;     # Zero if not specified explicitly.
     $v->part( 2 ) == 0;     # ditto
@@ -194,10 +196,10 @@ Version object always has at least 3 parts.
 
 The second part defines the release status: odd numbers denotes a trial release.
 
-    $v = Version::Dotted::Odd->new( v1.0 ); # $v == v1.0.0
-    $v->is_trial;                           # false
-    $v += v0.1;                             # $v == v1.1.0
-    $v->is_trial;                           # true
+    $v = qv( v1.0 );        # $v == v1.0.0
+    $v->is_trial;           # false
+    $v += v0.1;             # $v == v1.1.0
+    $v->is_trial;           # true
 
 =back
 
