@@ -26,11 +26,13 @@
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     use Version::Dotted::Semantic;
+#pod     use Version::Dotted::Semantic;              # import nothing
+#pod     use Version::Dotted::Semantic qw{ qv };     # import qv
 #pod
 #pod     # Construct:
-#pod     $v = Version::Dotted::Semantic->new( v1 );          # v1.0.0 (at least 3 parts)
-#pod     $v = Version::Dotted::Semantic->new( 'v1.2.3.4' );  # v1.2.3.4
+#pod     $v = Version::Dotted::Semantic->new( v1 );  # v1.0.0 (at least 3 parts)
+#pod     $v = qv( v1 );                  # v1.0.0 (at least 3 parts)
+#pod     $v = qv( 'v1.2.3.4' );          # v1.2.3.4
 #pod
 #pod     # Get parts by name (indexing also works):
 #pod     $int = $v->part( 'major' );     # Always defined.
@@ -65,7 +67,7 @@
 #pod
 #pod Version object always has at least 3 parts.
 #pod
-#pod     $v = Version::Dotted::Semantic->new( v1 );
+#pod     $v = qv( v1 );          # == v1.0.0
 #pod     $v->part( 0 ) == 1;     # Parts 0, 1, 2 are always defined.
 #pod     $v->part( 1 ) == 0;     # Zero if not specified explicitly.
 #pod     $v->part( 2 ) == 0;     # ditto
@@ -86,10 +88,10 @@
 #pod
 #pod The number of parts defines release status: more than 3 parts denotes trial release.
 #pod
-#pod     $v = Version::Dotted::Semantic->new( v1 );  # $v == v1.0.0
-#pod     $v->is_trial;                               # false
-#pod     $v->bump( 'trial' );                        # $v == v1.0.0.1
-#pod     $v->is_trial;                               # true
+#pod     $v = qv( v1 );          # $v == v1.0.0
+#pod     $v->is_trial;           # false
+#pod     $v->bump( 'trial' );    # $v == v1.0.0.1
+#pod     $v->is_trial;           # true
 #pod
 #pod =back
 #pod
@@ -279,7 +281,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: TODO
-our $VERSION = 'v0.0.0_01'; # TRIAL VERSION
+our $VERSION = 'v0.0.0_02'; # TRIAL VERSION
 
 use parent 'Version::Dotted';
 
@@ -419,18 +421,20 @@ Version::Dotted::Semantic - TODO
 
 =head1 VERSION
 
-Version v0.0.0_01, released on 2016-12-25 00:26 UTC.
+Version v0.0.0_02, released on 2016-12-25 22:38 UTC.
 This is a B<trial release>.
 
 =for test_synopsis my ( $v, $int );
 
 =head1 SYNOPSIS
 
-    use Version::Dotted::Semantic;
+    use Version::Dotted::Semantic;              # import nothing
+    use Version::Dotted::Semantic qw{ qv };     # import qv
 
     # Construct:
-    $v = Version::Dotted::Semantic->new( v1 );          # v1.0.0 (at least 3 parts)
-    $v = Version::Dotted::Semantic->new( 'v1.2.3.4' );  # v1.2.3.4
+    $v = Version::Dotted::Semantic->new( v1 );  # v1.0.0 (at least 3 parts)
+    $v = qv( v1 );                  # v1.0.0 (at least 3 parts)
+    $v = qv( 'v1.2.3.4' );          # v1.2.3.4
 
     # Get parts by name (indexing also works):
     $int = $v->part( 'major' );     # Always defined.
@@ -465,7 +469,7 @@ This is subclass of C<Version::Dotted>. Three features distinct it from the pare
 
 Version object always has at least 3 parts.
 
-    $v = Version::Dotted::Semantic->new( v1 );
+    $v = qv( v1 );          # == v1.0.0
     $v->part( 0 ) == 1;     # Parts 0, 1, 2 are always defined.
     $v->part( 1 ) == 0;     # Zero if not specified explicitly.
     $v->part( 2 ) == 0;     # ditto
@@ -486,10 +490,10 @@ First four parts have individual names:
 
 The number of parts defines release status: more than 3 parts denotes trial release.
 
-    $v = Version::Dotted::Semantic->new( v1 );  # $v == v1.0.0
-    $v->is_trial;                               # false
-    $v->bump( 'trial' );                        # $v == v1.0.0.1
-    $v->is_trial;                               # true
+    $v = qv( v1 );          # $v == v1.0.0
+    $v->is_trial;           # false
+    $v->bump( 'trial' );    # $v == v1.0.0.1
+    $v->is_trial;           # true
 
 =back
 
